Crate agentknock

Crate agentknock 

Agentknock is primarily a command-line application.

Start with the Agentknock README for installation, usage, and project documentation.

The public items below form the unstable Agentknock embedding API. Direct use of this API is not currently recommended.

Structs

ApplicationInfo
Identifies the application that uses the Agentknock library.
Client
Performs Agentknock operations using one local pairing.
GitSignRequest
Describes one Git signature requested by a command invocation.
PairingSas
A short authentication string for verifying an initial pairing.
SecretUseInvocation
Identifies and authenticates operations that belong to one command invocation.
SecretUseOutput
Secret material and related authorization returned for an invocation.
SecretUseRequest
Describes an invocation request that selects one or more secrets.
SshSecretUse
An SSH secret made available to a command invocation.

Enums

ConfigurationError
An error reading or updating local Agentknock state.
DenialReason
The reason that the device denied an authorization request.
ExecutableMode
The form of a selected executable.
GitSignProgress
A stage reported while a Git signature request is running.
PairingProgress
A stage reported while a pairing operation is running.
PairingRemoveError
An error removing an active pairing.
PairingStatus
The state of the pairing stored on this client.
RequestError
An error during an operation that communicates with the relay or device.
Secret
Metadata for a secret available from the paired device.
SecretListProgress
A stage reported while a secret-list request is running.
SecretUpload
A secret to upload to the device.
SecretUploadError
An error uploading a secret.
SecretUploadMode
How an uploaded secret changes device state after user acceptance.
SecretUploadProgress
A stage reported while a secret upload is running.
SecretUseOperation
A command operation described by an invocation request.
SecretUseProgress
A stage reported while an invocation request is running.
StreamKind
Describes how a command’s standard stream is connected.

Type Aliases

Secrets
Secret metadata keyed by secret name.