#[non_exhaustive]pub enum SecretListProgress {
Preparing,
WaitingForDelivery,
WaitingForResponse,
Completing,
Completed,
}Expand description
A stage reported while a secret-list request is running.
A successful operation reports Preparing, WaitingForDelivery,
optionally one or more WaitingForResponse updates, Completing, and
Completed, in that order. An operation that fails stops without reporting
Completed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Preparing
Agentknock is reading local state and preparing the protected request.
WaitingForDelivery
The request is waiting to be delivered to the device.
WaitingForResponse
The device has received the request but hasn’t returned a response.
Completing
Agentknock is validating the response and handing off the completion.
Completed
The operation has finished successfully.