Agentknock is primarily a command-line application.
Start with the Agentknock README for installation, usage, and project documentation.
The public items below form the unstable Agentknock embedding API. Direct use of this API is not currently recommended.
Structs
- Application
Info - Identifies the application that uses the Agentknock library.
- Client
- Performs Agentknock operations using one local pairing.
- GitSign
Request - Describes one Git signature requested by a command invocation.
- Pairing
Sas - A short authentication string for verifying an initial pairing.
- Secret
UseInvocation - Identifies and authenticates operations that belong to one command invocation.
- Secret
UseOutput - Secret material and related authorization returned for an invocation.
- Secret
UseRequest - Describes an invocation request that selects one or more secrets.
- SshSecret
Use - An SSH secret made available to a command invocation.
Enums
- Configuration
Error - An error reading or updating local Agentknock state.
- Denial
Reason - The reason that the device denied an authorization request.
- Executable
Mode - The form of a selected executable.
- GitSign
Progress - A stage reported while a Git signature request is running.
- Pairing
Progress - A stage reported while a pairing operation is running.
- Pairing
Remove Error - An error removing an active pairing.
- Pairing
Status - The state of the pairing stored on this client.
- Request
Error - An error during an operation that communicates with the relay or device.
- Secret
- Metadata for a secret available from the paired device.
- Secret
List Progress - A stage reported while a secret-list request is running.
- Secret
Upload - A secret to upload to the device.
- Secret
Upload Error - An error uploading a secret.
- Secret
Upload Mode - How an uploaded secret changes device state after user acceptance.
- Secret
Upload Progress - A stage reported while a secret upload is running.
- Secret
UseOperation - A command operation described by an invocation request.
- Secret
UseProgress - A stage reported while an invocation request is running.
- Stream
Kind - Describes how a command’s standard stream is connected.
Type Aliases
- Secrets
- Secret metadata keyed by secret name.